@@ -26,7 +26,7 @@ def create_new_project(session):
         sorted([p["name"] for p in projects if "invoice" not in p["name"]]),
         "Select the team:",
     )
-
+    print(option)
     clearConsole()
     num = get_latest_proj()
     team = [t for t in projects if option.lower() == t["name"].lower()][0]
@@ -34,7 +34,7 @@ def create_new_project(session):
 
     dest_folder = None
 
-    for child in projects[index]["children"]:
+    for child in team["children"]:
         if child["name"] == "Projects":
             dest_folder = child
 
